@@ -1,7 +1,7 @@
 /*
  * This file is part of budgie-desktop.
  *
- * Copyright © 2015-2019 Budgie Desktop Developers
+ * Copyright © 2015-2020 Budgie Desktop Developers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,24 +25,22 @@ typedef struct _BudgiePluginIface BudgiePluginIface;
 #define BUDGIE_TYPE_PLUGIN (budgie_plugin_get_type())
 #define BUDGIE_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_CAST((o), BUDGIE_TYPE_PLUGIN, BudgiePlugin))
 #define BUDGIE_IS_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_TYPE((o), BUDGIE_TYPE_PLUGIN))
-#define BUDGIE_PLUGIN_IFACE(o)                                                                     \
-        (G_TYPE_CHECK_INTERFACE_CAST((o), BUDGIE_TYPE_PLUGIN, BudgiePluginIface))
+#define BUDGIE_PLUGIN_IFACE(o) (G_TYPE_CHECK_INTERFACE_CAST((o), BUDGIE_TYPE_PLUGIN, BudgiePluginIface))
 #define BUDGIE_IS_PLUGIN_IFACE(o) (G_TYPE_CHECK_INTERFACE_TYPE((o), BUDGIE_TYPE_PLUGIN))
-#define BUDGIE_PLUGIN_GET_IFACE(o)                                                                 \
-        (G_TYPE_INSTANCE_GET_INTERFACE((o), BUDGIE_TYPE_PLUGIN, BudgiePluginIface))
+#define BUDGIE_PLUGIN_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE((o), BUDGIE_TYPE_PLUGIN, BudgiePluginIface))
 
 /**
  * BudgiePluginIface
  */
 struct _BudgiePluginIface {
-        GTypeInterface parent_iface;
+	GTypeInterface parent_iface;
 
-        BudgieApplet *(*get_panel_widget)(BudgiePlugin *self, gchar *uuid);
+	BudgieApplet* (*get_panel_widget)(BudgiePlugin* self, gchar* uuid);
 
-        gpointer padding[4];
+	gpointer padding[4];
 };
 
-BudgieApplet *budgie_plugin_get_panel_widget(BudgiePlugin *self, gchar *uuid);
+BudgieApplet* budgie_plugin_get_panel_widget(BudgiePlugin* self, gchar* uuid);
 
 GType budgie_plugin_get_type(void);
 
